#ifndef EXERCISEDIALOG_H
#define EXERCISEDIALOG_H

#include <QtGui>

class ExerciseDialog : public QDialog
{
    Q_OBJECT

public:
    explicit ExerciseDialog(QWidget *parent = 0);
    void load(QList <QString>);
    ~ExerciseDialog();
signals:
    void exerciseName(QString name);
    void destroyDialog();


private:
    void closeEvent(QCloseEvent *event);
    QStandardItemModel *model;
    QListView *lstExercises;
    QPushButton *btnStart;

    bool closing;

private slots:
    void start();

};

#endif // EXERCISEDIALOG_H
